API docs for “spamfighter.plugins.null_partner_authorizer_provider.NullPartnerAuthorizerProvider”

# Class s.p.n.NullPartnerAuthorizerProvider(object):

Part of spamfighter.plugins.null_partner_authorizer_provider View Source View In Hierarchy

Провайдер авторизации партнеров без логинов/паролей.

Method | __init__ | Конструктор.
Method | name | Получить имя плагина.
Method | getPartnerAuthorizer | Получить механизм авторизации партнеров.

def __init__(self): (source)
Конструктор.

def name(self): (source)
Получить имя плагина.

Returns | имя плагина (type: `str` )

def getPartnerAuthorizer(self): (source)
Получить механизм авторизации партнеров.

Returns | домен по умолчанию. (type: `spamfighter.interfaces.IPartnerAuthorizer` )